@@ -16,8 +16,11 @@ package Test::CVE;
     perl     => 1,
     minimum  => 0,
     cpansa   => "https://cpan-security.github.io/cpansa-feed/cpansa.json",
-    make_pl  => "Makefile.PL",
     cpanfile => "cpanfile",
+    meta_jsn => "META.json",
+    meta_yml => "META.yml",     # NYI
+    make_pl  => "Makefile.PL",
+    build_pl => "Build.PL",     # NYI
     want     => [],
     );
 
@@ -33,7 +36,7 @@ package Test::CVE;
 use 5.014000;
 use warnings;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use version;
 use Carp;
@@ -57,8 +60,11 @@ sub new {
     $self{verbose}  //= 0;
     $self{width}    //= $ENV{COLUMNS} // 80;
     $self{want}     //= [];
-    $self{make_pl}  ||= "Makefile.PL";
     $self{cpanfile} ||= "cpanfile";
+    $self{meta_jsn} ||= "META.json";
+    $self{meta_yml} ||= "META.yml";
+    $self{make_pl}  ||= "Makefile.PL";
+    $self{build_pl} ||= "Build.PL";
     $self{CVE}        = {};
     bless \%self => $class;
     } # new
@@ -116,7 +122,7 @@ sub _read_MakefilePL {
     $mf ||= $self->{make_pl};
 
     $self->{verbose} and warn "Reading $mf ...\n";
-    open my $fh, "<", $mf or croak "$mf: $!\n";
+    open my $fh, "<", $mf or return $self;
     my $mfc = do { local $/; <$fh> };
     close $fh;
 
@@ -197,9 +203,10 @@ sub _read_cpanfile {
 
 sub _read_META {
     my ($self, $mmf) = @_;
-    $mmf ||= "MYMETA.json";
+    $mmf ||= first { length && -s } $self->{meta_jsn}, "META.json", "MYMETA.json";
 
     -s $mmf or return;
+    $self->{meta_jsn} = $mmf;
     $self->{verbose} and warn "Reading $mmf ...\n";
     open my $fh, "<", $mmf or croak "$mmf: $!\n";
     local $/;
@@ -207,10 +214,10 @@ sub _read_META {
     close $fh;
 
     unless ($self->{mf}) {
-	$self->{mf}{release} = $j->{name} =~ s{::}{-}gr;
-	$self->{mf}{version} = $j->{version};
-	$self->{mf}{name}    = $j->{name} =~ s{-}{::}gr;
-	$self->{prereq}{$self->{mf}{release}}{v}{$j->{version} // "-"} = "current";
+	my $rls = $self->{mf}{release} = $j->{name} =~ s{::}{-}gr;
+	my $vsn = $self->{mf}{version} = $j->{version};
+	my $nm  = $self->{mf}{name}    = $j->{name} =~ s{-}{::}gr;
+	$self->{prereq}{$rls}{v}{$vsn // "-"} = "current";
 	}
 
     my $pr = $j->{prereqs} or return $self;
@@ -253,13 +260,16 @@ sub want {
 
 sub test {
     my $self = shift;
+    my $meta = 0;
 
     $self->{mf}      or $self->_read_MakefilePL;
+    $self->{mf}      or $self->_read_META && $meta++;
     my $rel  = $self->{mf}{release} or return $self;
+    $self->{verbose} and warn "Processing for $self->{mf}{release} ...\n";
 
-    $self->{j}       or $self->_read_cpansa;
+    $self->{j}{mod}  or $self->_read_cpansa;
     @{$self->{want}} or $self->_read_cpanfile           if $self->{deps};
-    @{$self->{want}} or $self->_read_META               if $self->{deps};
+    @{$self->{want}} or $self->_read_META               if $self->{deps} && !$meta;
     @{$self->{want}} or $self->_read_META ("META.json") if $self->{deps};
 
     $self->{j}{db}{$rel} and unshift @{$self->{want}} => $rel;
